==> vpn-user-portal-3.3.1.tgz: share/doc/vpn-user-portal/README.md <==
**Summary**: User and admin portal for Let's Connect! and eduVPN 

**Description**: The user and admin portal and API for eduVPN / Let's Connect! 
allowing for self-management by users and administrative tasks by designated 
administrators.

**License**:  AGPL-3.0-or-later

[![builds.sr.ht status](https://builds.sr.ht/~fkooman/vpn-user-portal.svg)](https://builds.sr.ht/~fkooman/vpn-user-portal)

# Introduction

This project contains the user and admin portal for the Let's Connect! and 
eduVPN software.

# Issue Tracker

Find our issue tracker [here](https://todo.sr.ht/~eduvpn/server). You can also 
submit an issue through mail. 

Please mention the version of eduVPN / Let's Connect! server you are running 
and _only_ report issues with the _server_ here!

# Contributing

Thank you for taking the time to contribute to eduVPN / Let's Connect!. 

We are very happy to receive bug fixes and translation updates! Please create
an entry in the [Issue Tracker](#issue-tracker) as well. If you want to 
see/develop new features, or introduce big(ger) changes, please 
[talk](mailto:eduvpn-support@lists.geant.org) to us before you start working on 
it to prevent you doing to work and having it rejected.

Furthermore, in order for us to be able to accept your contributions, if they 
are big enough to warrant protection under copyright, we'd like 
to ask you to sign our "CLA" and send it back to us. 

You can find the CLA [here](https://commonsconservancy.org/resources/). Pick
the correct one, either for "legal entities" or "individuals" and mail it to
[legaldocuments@commonsconservancy.org](mailto:legaldocuments@commonsconservancy.org) 
as stated in the document. Please add 
[eduvpn-support@lists.geant.org](mailto:eduvpn-support@lists.geant.org) to the 
CC field.

**NOTE**: signing the CLA will not automatically guarantee your contribution 
will be accepted and included in the software! 

Thanks again for wanting to contribute to eduVPN / Let's Connect!

## Code Quality / Style

If you want to contribute, make sure your code makes it through static code 
analysis, does not break the unit tests and is properly formatted.

See the `Makefile` target and run `make all` to run all of them. Refer to our
[Development Setup](https://github.com/eduvpn/documentation/blob/v3/DEVELOPMENT_SETUP.md) 
documentation on how to install and run those tools.

==> vpn-user-portal-3.5.6.tgz: share/doc/vpn-user-portal/README.md <==
**Summary**: User and admin portal for Let's Connect! and eduVPN 

**Description**: The user and admin portal and API for eduVPN / Let's Connect! 
allowing for self-management by users and administrative tasks by designated 
administrators.

**License**:  AGPL-3.0-or-later

[![builds.sr.ht status](https://builds.sr.ht/~fkooman/vpn-user-portal.svg)](https://builds.sr.ht/~fkooman/vpn-user-portal)

# Introduction

This project contains the user and admin portal for the Let's Connect! and 
eduVPN software.

# Issue Tracker

Find our issue tracker [here](https://todo.sr.ht/~eduvpn/server). You can also 
submit an issue through mail. 

Please mention the version of eduVPN / Let's Connect! server you are running 
and _only_ report issues with the _server_ here!

# Contributing

Thank you for taking the time to contribute to eduVPN / Let's Connect!. 

We are very happy to receive bug fixes and translation updates! Please create
an entry in the [Issue Tracker](#issue-tracker) as well. If you want to 
see/develop new features, or introduce big(ger) changes, please 
[talk](mailto:eduvpn-support@lists.geant.org) to us before you start working on 
it to prevent you doing to work and having it rejected.

Furthermore, in order for us to be able to accept your contributions, if they 
are big enough to warrant protection under copyright, we'd like 
to ask you to sign our "CLA" and send it back to us. 

You can find the CLA [here](https://commonsconservancy.org/resources/). Pick
the correct one, either for "legal entities" or "individuals" and mail it to
[legaldocuments@commonsconservancy.org](mailto:legaldocuments@commonsconservancy.org) 
as stated in the document. Please add 
[eduvpn-support@lists.geant.org](mailto:eduvpn-support@lists.geant.org) to the 
CC field.

**NOTE**: signing the CLA will not automatically guarantee your contribution 
will be accepted and included in the software! 

Thanks again for wanting to contribute to eduVPN / Let's Connect!

## Code Quality / Style

If you want to contribute, make sure your code makes it through static code 
analysis, does not break the unit tests and is properly formatted.

See the `Makefile` target and run `make all` to run all of them. 

Refer to [Development Setup](https://codeberg.org/eduVPN/development) on how to
install and run those tools.
